#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Simple Sliding Window N-Gram Extractor """


from typing import List

from baseblock import BaseObject, TextUtils


class SlidingWindowExtract(BaseObject):
    """ Simple Sliding Window N-Gram Extractor """

    def __init__(self):
        """ Change Log

        Created:
            26-Oct-2022
            craigtrim@gmail.com
        """
        BaseObject.__init__(self, __name__)

    def process(self,
                tokens: List[str],
                gram_level: int,
                skip_gram: bool = False) -> list:
        """ Extract Bigrams

        Args:
            tokens (List[str]): the incoming tokens
            gram_level (int): the gram level to extract at
            skip_gram (bool, False): skip every other gram. Defaults to False.

        Returns:
            list: a list of bigrams (or skipgrams)
        """

        if not skip_gram:
            return TextUtils.sliding_window(
                tokens=tokens,
                window_size=gram_level)

        tokens_even = []
        tokens_odd = []

        for i in range(len(tokens)):
            if i % 2 != 0:
                tokens_odd.append(tokens[i])
            else:
                tokens_even.append(tokens[i])

        grams_odd = TextUtils.sliding_window(
            tokens=tokens_odd,
            window_size=gram_level)

        grams_even = TextUtils.sliding_window(
            tokens=tokens_even,
            window_size=gram_level)

        return grams_odd + grams_even



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Text Tokenization API """


from functools import lru_cache


class Tokenizer(object):
    """ Text Tokenization API """

    def __init__(self):
        self._spacy = None
        self._custom = None
        self._whitespace = None

    @lru_cache
    def spacy(self,
              input_text: str) -> list:
        """Tokenize with spaCy

        Args:
            input_text (str): input text of any length

        Returns:
            list: list of tokens
        """
        if not self._spacy:
            from fast_sentence_tokenize.svc import TokenizeUseSpacy
            self._spacy = TokenizeUseSpacy().process

        return self._spacy(input_text)

    @lru_cache
    def whitespace(self,
                   input_text: str) -> list:
        """Tokenize using Whitespace

        Args:
            input_text (str): input text of any length

        Returns:
            list: list of tokens
        """
        if not self._whitespace:
            from fast_sentence_tokenize.svc import TokenizeUseWhitespace
            self._whitespace = TokenizeUseWhitespace().process

        return self._whitespace(input_text)

    @lru_cache
    def input_text(self,
                   input_text: str) -> list:
        """Tokenize with Custom Tokenizer

        Args:
            input_text (str): input text of any length

        Returns:
            list: list of tokens
        """
        if not self._custom:
            from fast_sentence_tokenize.svc import TokenizeUseGraffl
            self._custom = TokenizeUseGraffl().process

        return self._custom(input_text)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
"""  Perform Tokenization with spaCy  """


from spacy.lang.en import English
from spacy.tokenizer import Tokenizer


class TokenizeUseSpacy(object):
    """  Perform Tokenization with spaCy
    Reference:
        https://spacy.io/api/tokenizer """

    __tokenizer = None

    def __init__(self,
                 input_text: str):
        """
        Created:
            29-Sept-2021
            craigtrim@gmail.com
        :param input_text:
        """
        self._input_text = input_text

    def process(self) -> list:
        if not self.__tokenizer:
            nlp = English()
            self.__tokenizer = Tokenizer(nlp.vocab)

        return self.__tokenizer(self._input_text)



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Simple Sliding Window N-Gram Extractor """


from typing import List

from baseblock import BaseObject, Enforcer

from fast_sentence_tokenize.svc import SlidingWindowExtract

extract_ngrams = SlidingWindowExtract().process


class NGrams(BaseObject):
    """ Simple Sliding Window N-Gram Extractor """

    def __init__(self,
                 tokens: List[str]):
        """ Change Log

        Created:
            26-Oct-2022
            craigtrim@gmail.com

        Args:
            tokens (List[str]): the incoming tokens
        """
        BaseObject.__init__(self, __name__)
        if self.isEnabledForDebug:
            Enforcer.is_list_of_str(tokens)

        self._tokens = tokens

    def bigrams(self,
                skip_gram: bool = False) -> list:
        """ Extract Bigrams

        Args:
            skip_gram (int, optional): skip every N grams. Defaults to 0.

        Returns:
            list: a list of bigrams (or skipgrams)
        """
        return extract_ngrams(tokens=self._tokens,
                              gram_level=2,
                              skip_gram=skip_gram)

    def trigrams(self,
                 skip_gram: bool = False) -> list:
        """ Extract Trigrams

        Args:
            skip_gram (int, optional): skip every N grams. Defaults to 0.

        Returns:
            list: a list of trigrams (or skipgrams)
        """
        return extract_ngrams(tokens=self._tokens,
                              gram_level=3,
                              skip_gram=skip_gram)

    def quadgrams(self,
                  skip_gram: bool = False) -> list:
        """ Extract Quadgrams

        Args:
            skip_gram (int, optional): skip every N grams. Defaults to 0.

        Returns:
            list: a list of quadgrams (or skipgrams)
        """
        return extract_ngrams(tokens=self._tokens,
                              gram_level=4,
                              skip_gram=skip_gram)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fast_sentence_tokenize',
 'fast_sentence_tokenize.bp',
 'fast_sentence_tokenize.datablock',
 'fast_sentence_tokenize.datablock.dto',
 'fast_sentence_tokenize.dmo',
 'fast_sentence_tokenize.svc']

package_data = \
{'': ['*']}

install_requires = \
['baseblock', 'nltk', 'spacy==3.3']

setup_kwargs = {
    'name': 'fast-sentence-tokenize',
    'version': '0.1.10',
    'description': 'Fast and Efficient Sentence Tokenization',
    'long_description': '# Fast Sentence Tokenizer (fast-sentence-tokenize)\nBest in class tokenizer\n\n## Usage\n\n### Import\n```python\nfrom fast_sentence_tokenize import fast_sentence_tokenize\n```\n\n### Call Tokenizer\n```python\nresults = fast_sentence_tokenize("isn\'t a test great!!?")\n```\n\n### Results\n```json\n[\n   "isn\'t",\n   "a",\n   "test",\n   "great",\n   "!",\n   "!",\n   "?"\n]\n```\nNote that whitespace is not preserved in the output by default.\n\nThis generally results in a more accurate parse from downstream components, but may make the reassembly of the original sentence more challenging.\n\n### Preserve Whitespace\n```python\nresults = fast_sentence_tokenize("isn\'t a test great!!?", eliminate_whitespace=False)\n```\n### Results\n```json\n[\n   "isn\'t ",\n   "a ",\n   "test ",\n   "great",\n   "!",\n   "!",\n   "?"\n]\n```\n\nThis option preserves whitespace.\n\nThis is useful if you want to re-assemble the tokens using the pre-existing spacing\n```python\nassert \'\'.join(tokens) == input_text\n```\n',
    'author': 'Craig Trim',
    'author_email': 'craigtrim@gmail.com',
    'maintainer': 'Craig Trim',
    'maintainer_email': 'craigtrim@gmail.com',
    'url': 'https://github.com/craigtrim/fast-sentence-tokenize',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8.5,<4.0.0',
}


setup(**setup_kwargs)
